@@ -1,6 +1,6 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
-    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
+    Copyright (C) 2017 Norbert Truchsess <norbert.truchsess@t-online.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -267,7 +267,7 @@ void CCanvas::buildHelpText()
                                     "<p>Patient Users:<p>"
                                     "<ul>"
                                     "<li><a href='ShowQuickStart'>Quick Start Guide.</a></li>"
-                                    "<li><a href='https://github.com/Maproom/qmapshack/wiki/DocGettingStarted#markdown-header-add-maps'>Getting Started.</a></li>"
+                                    "<li><a href='https://github.com/Maproom/qmapshack/wiki/DocGettingStarted#add-maps'>Getting Started.</a></li>"
                                     "<li><a href='https://github.com/Maproom/qmapshack/wiki/DocInstallMapDem'>Install Maps & DEM</a></li>"
                                     "<li><a href='https://github.com/Maproom/qmapshack/wiki/DocBasicsMapDem'>Basics Maps & DEM.</a></li>"
                                     "<li><a href='https://github.com/Maproom/qmapshack/wiki/DocMapDemSources'>Sources for Maps</a></li>"
@@ -554,10 +554,10 @@ void CCanvas::resizeEvent(QResizeEvent * e)
     const QRect& r = rect();
 
     // move map loading indicator to new center of canvas
-    QPoint p1(mapLoadIndicator->width()>>1, mapLoadIndicator->height()>>1);
+    QPoint p1(mapLoadIndicator->width() >> 1, mapLoadIndicator->height() >> 1);
     mapLoadIndicator->move(r.center() - p1);
 
-    QPoint p2(demLoadIndicator->width()>>1, demLoadIndicator->height()>>1);
+    QPoint p2(demLoadIndicator->width() >> 1, demLoadIndicator->height() >> 1);
     demLoadIndicator->move(r.center() - p2);
 
     textStatusMessages->move(X_OFF_STATUS, Y_OFF_STATUS);
@@ -569,6 +569,8 @@ void CCanvas::resizeEvent(QResizeEvent * e)
     labelHelp->move(25, 25);
     labelHelp->resize(s);
     buildHelpText();
+
+    emit sigResize(e->size());
 }
 
 void CCanvas::paintEvent(QPaintEvent*)
@@ -612,12 +614,12 @@ void CCanvas::paintEvent(QPaintEvent*)
             rt->draw(p, rect());
         }
     }
-    mouse->draw(p, needsRedraw, rect());
 
+    drawScale(p);
+    mouse->draw(p, needsRedraw, rect());
 
     drawStatusMessages(p);
     drawTrackStatistic(p);
-    drawScale(p);
 
     p.end();
     needsRedraw = eRedrawNone;
@@ -646,8 +648,8 @@ void CCanvas::mouseMoveEvent(QMouseEvent * e)
 {
     QPointF pos = e->pos();
     map->convertPx2Rad(pos);
-    qreal ele = dem->getElevationAt(pos);
-    qreal slope = dem->getSlopeAt(pos);
+    qreal ele = dem->getElevationAt(pos, true);
+    qreal slope = dem->getSlopeAt(pos, true);
     emit sigMousePosition(pos * RAD_TO_DEG, ele, slope);
 
     mouse->mouseMoveEvent(e);
@@ -745,19 +747,19 @@ void CCanvas::keyPressEvent(QKeyEvent * e)
 
     /* move the map with keys up, down, left and right */
     case Qt::Key_Up:
-        moveMap(QPointF(0,  height()/4));
+        moveMap(QPointF(0,  height() / 4));
         break;
 
     case Qt::Key_Down:
-        moveMap(QPointF(0, -height()/4));
+        moveMap(QPointF(0, -height() / 4));
         break;
 
     case Qt::Key_Left:
-        moveMap(QPointF( width()/4, 0));
+        moveMap(QPointF( width() / 4, 0));
         break;
 
     case Qt::Key_Right:
-        moveMap(QPointF(-width()/4, 0));
+        moveMap(QPointF(-width() / 4, 0));
         break;
 
     case Qt::Key_Escape:
@@ -871,7 +873,7 @@ void CCanvas::drawScale(QPainter& p, QRectF drawRect)
     p.drawLine(pt1, pt2 + QPoint(9, 0));
 
 
-    QPoint pt3(pt2.x() + (pt1.x() - pt2.x())/2, pt2.y());
+    QPoint pt3(pt2.x() + (pt1.x() - pt2.x()) / 2, pt2.y());
 
     QString val, unit;
     IUnit::self().meter2distance(d, val, unit);
@@ -960,7 +962,7 @@ void CCanvas::slotUpdateTrackInfo(bool updateVisuals)
         QString text;
         if(isShowTrackSummary())
         {
-            text += trk->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowActivity);
+            text += trk->getInfo(IGisItem::eFeatureShowName | IGisItem::eFeatureShowActivity);
         }
 
         if(isShowMinMaxSummary())
@@ -1250,7 +1252,7 @@ void CCanvas::showProfile(bool yes)
 {
     if(nullptr != plotTrackProfile)
     {
-        plotTrackProfile->setVisible(yes && CMainWindow::self().isShowTrackProfile());
+        plotTrackProfile->setVisible(yes && isShowTrackProfile());
     }
 }
 
