@@ -1,5 +1,5 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include "gis/CGisDatabase.h"
 #include "gis/CGisWorkspace.h"
 #include "gis/db/CDBProject.h"
+#include "gis/db/CResolveDatabaseConflict.h"
 #include "gis/db/CSelectSaveAction.h"
 #include "gis/db/IDB.h"
 #include "gis/db/macros.h"
@@ -269,9 +270,9 @@ void CDBProject::postStatus(bool updateLostFound)
 }
 
 
-int CDBProject::checkForAction2(IGisItem * item, quint64 &itemId, QString& hashItem, QSqlQuery &query)
+CDBProject::action_e CDBProject::checkForAction2(IGisItem * item, quint64 &itemId, QString& hashItem, action_e& action2ForAll, QSqlQuery &query)
 {
-    int action = eActionNone;
+    action_e action = eActionNone;
 
     query.prepare("SELECT hash, last_user, last_change FROM items WHERE id=:id");
     query.bindValue(":id", itemId);
@@ -297,28 +298,8 @@ int CDBProject::checkForAction2(IGisItem * item, quint64 &itemId, QString& hashI
             "your version and take the one from the database"
             ).arg(item->getNameEx()).arg(user).arg(date);
 
-        QMessageBox msgBox(QMessageBox::Question, tr("Conflict with database..."), msg, QMessageBox::NoButton, CMainWindow::self().getBestWidgetForParent());
-        QAbstractButton* pButClone  = msgBox.addButton(tr("Clone && Save"), QMessageBox::YesRole);
-        QAbstractButton* pButForce  = msgBox.addButton(tr("Force Save"),    QMessageBox::ApplyRole);
-        QAbstractButton* pButUpdate = msgBox.addButton(tr("Take remote"),   QMessageBox::DestructiveRole);
-        msgBox.addButton(QMessageBox::Abort);
-
-        CProgressDialog::setAllVisible(false);
-        msgBox.exec();
-        CProgressDialog::setAllVisible(true);
-
-        if(msgBox.clickedButton() == pButClone)
-        {
-            action = eActionClone;
-        }
-        else if(msgBox.clickedButton() == pButForce)
-        {
-            action = eActionUpdate;
-        }
-        else if(msgBox.clickedButton() == pButUpdate)
-        {
-            action = eActionReload;
-        }
+        CResolveDatabaseConflict dialog (msg, item, action2ForAll, CMainWindow::self().getBestWidgetForParent());
+        action = dialog.getAction();
     }
     else
     {
@@ -332,7 +313,7 @@ int CDBProject::checkForAction2(IGisItem * item, quint64 &itemId, QString& hashI
     return action;
 }
 
-void CDBProject::updateItem(IGisItem *&item, quint64 idItem, QSqlQuery &query)
+void CDBProject::updateItem(IGisItem *&item, quint64 idItem, action_e& action2ForAll, QSqlQuery &query)
 {
     // serialize complete history of item
     QByteArray data;
@@ -356,7 +337,7 @@ void CDBProject::updateItem(IGisItem *&item, quint64 idItem, QSqlQuery &query)
     query.bindValue(":icon",    buffer.data());
     query.bindValue(":name",    item->getName());
     query.bindValue(":date",    item->getTimestamp());
-    query.bindValue(":comment", item->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowFullText));
+    query.bindValue(":comment", item->getInfo(IGisItem::eFeatureShowName | IGisItem::eFeatureShowFullText));
     query.bindValue(":data",    data);
     query.bindValue(":hash",    item->getHash());
     query.bindValue(":id",      idItem);
@@ -375,7 +356,7 @@ void CDBProject::updateItem(IGisItem *&item, quint64 idItem, QSqlQuery &query)
         // 1) the hash is different because another user changed the item
         // 2) the id was not found because another user removed the item
         // 3) the items was completely identical, therefore no row was affected.
-        int action = checkForAction2(item, idItem, hashInDb, query);
+        int action = checkForAction2(item, idItem, hashInDb, action2ForAll, query);
 
         switch(action)
         {
@@ -404,7 +385,7 @@ void CDBProject::updateItem(IGisItem *&item, quint64 idItem, QSqlQuery &query)
             query.bindValue(":icon",    buffer.data());
             query.bindValue(":name",    item->getName());
             query.bindValue(":date",    item->getTimestamp());
-            query.bindValue(":comment", item->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowFullText));
+            query.bindValue(":comment", item->getInfo(IGisItem::eFeatureShowName | IGisItem::eFeatureShowFullText));
             query.bindValue(":data",    data);
             query.bindValue(":hash",    item->getHash());
             query.bindValue(":id",      idItem);
@@ -457,7 +438,7 @@ quint64 CDBProject::insertItem(IGisItem * item, QSqlQuery &query)
     query.bindValue(":icon",    buffer.data());
     query.bindValue(":name",    item->getName());
     query.bindValue(":date",    item->getTimestamp());
-    query.bindValue(":comment", item->getInfo(IGisItem::eFeatureShowName|IGisItem::eFeatureShowFullText));
+    query.bindValue(":comment", item->getInfo(IGisItem::eFeatureShowName | IGisItem::eFeatureShowFullText));
     query.bindValue(":data",    data);
     query.bindValue(":hash",    item->getHash());
     QUERY_EXEC(throw eReasonQueryFail);
@@ -480,7 +461,7 @@ quint64 CDBProject::insertItem(IGisItem * item, QSqlQuery &query)
     return idItem;
 }
 
-int CDBProject::checkForAction1(IGisItem * item, quint64& itemId, int& lastResult, QSqlQuery &query)
+CDBProject::action_e CDBProject::checkForAction1(IGisItem * item, quint64& itemId, CSelectSaveAction::result_e& action1ForAll, QSqlQuery &query)
 {
     int action = eActionNone;
 
@@ -505,9 +486,9 @@ int CDBProject::checkForAction1(IGisItem * item, quint64& itemId, int& lastResul
         if(!query.next())
         {
             // item is already in database but folder relation does not exit
-            int result  = lastResult;
+            CSelectSaveAction::result_e result  = action1ForAll;
 
-            if(lastResult == CSelectSaveAction::eResultNone)
+            if(action1ForAll == CSelectSaveAction::eResultNone)
             {
                 // Build the dialog to ask for user action
                 IGisItem * item1 = IGisItem::newGisItem(itemType, itemId, db, nullptr);
@@ -524,7 +505,7 @@ int CDBProject::checkForAction1(IGisItem * item, quint64& itemId, int& lastResul
                 result = dlg.getResult();
                 if(dlg.allOthersToo())
                 {
-                    lastResult = result;
+                    action1ForAll = result;
                 }
             }
 
@@ -563,18 +544,18 @@ int CDBProject::checkForAction1(IGisItem * item, quint64& itemId, int& lastResul
     }
     else
     {
-        action = eActionInsert|eActionLink;
+        action = eActionInsert | eActionLink;
     }
 
-    return action;
+    return (action_e)action;
 }
 
 bool CDBProject::save()
 {
-    return save(CSelectSaveAction::eResultNone);
+    return save(CSelectSaveAction::eResultNone, eActionNone);
 }
 
-bool CDBProject::save(int lastResult)
+bool CDBProject::save(CSelectSaveAction::result_e action1ForAll, action_e action2ForAll)
 {
     QSqlQuery query(db);
     bool stop       = false;
@@ -617,7 +598,7 @@ bool CDBProject::save(int lastResult)
 
             quint64 idItem = 0;
 
-            int action = checkForAction1(item, idItem, lastResult, query);
+            int action = checkForAction1(item, idItem, action1ForAll, query);
 
             if(action & eActionInsert)
             {
@@ -626,7 +607,7 @@ bool CDBProject::save(int lastResult)
 
             if(action & eActionUpdate)
             {
-                updateItem(item, idItem, query);
+                updateItem(item, idItem, action2ForAll, query);
             }
 
             if(action & eActionReload)
@@ -651,7 +632,7 @@ bool CDBProject::save(int lastResult)
                 query.bindValue(":child", idItem);
                 QUERY_EXEC(throw eReasonQueryFail);
             }
-            item->updateDecoration(IGisItem::eMarkNone, IGisItem::eMarkChanged|IGisItem::eMarkNotPart|IGisItem::eMarkNotInDB);
+            item->updateDecoration(IGisItem::eMarkNone, IGisItem::eMarkChanged | IGisItem::eMarkNotPart | IGisItem::eMarkNotInDB);
         }
         catch(reasons_e reason)
         {
@@ -699,7 +680,7 @@ bool CDBProject::save(int lastResult)
 }
 
 
-void CDBProject::showItems(CEvtD2WShowItems * evt)
+void CDBProject::showItems(CEvtD2WShowItems * evt, action_e action2ForAll)
 {
     bool restoreDlgDetails = false;
     if(evt->addItemsExclusively)
@@ -727,7 +708,7 @@ void CDBProject::showItems(CEvtD2WShowItems * evt)
             try
             {
                 QSqlQuery query(db);
-                updateItem(gisItem, item.id, query);
+                updateItem(gisItem, item.id, action2ForAll, query);
             }
             catch(int)
             {
@@ -776,7 +757,7 @@ void CDBProject::update()
     if(isChanged())
     {
         QString msg = tr("The project '%1' is about to update itself from the database. However there are changes not saved.").arg(getName());
-        int res = QMessageBox::question(CMainWindow::self().getBestWidgetForParent(), tr("Save changes?"), msg, QMessageBox::Save|QMessageBox::Ignore|QMessageBox::Abort, QMessageBox::Save);
+        int res = QMessageBox::question(CMainWindow::self().getBestWidgetForParent(), tr("Save changes?"), msg, QMessageBox::Save | QMessageBox::Ignore | QMessageBox::Abort, QMessageBox::Save);
 
         if(res == QMessageBox::Abort)
         {
@@ -875,13 +856,13 @@ void CDBProject::update()
                 {
                     // item is not connected to this project
                     item->updateFromDB(idItem, db);
-                    item->updateDecoration(IGisItem::eMarkNotPart|IGisItem::eMarkChanged, IGisItem::eMarkNone);
+                    item->updateDecoration(IGisItem::eMarkNotPart | IGisItem::eMarkChanged, IGisItem::eMarkNone);
                 }
             }
             else
             {
                 // item is not in the database at all.
-                item->updateDecoration(IGisItem::eMarkNotInDB|IGisItem::eMarkChanged, IGisItem::eMarkNone);
+                item->updateDecoration(IGisItem::eMarkNotInDB | IGisItem::eMarkChanged, IGisItem::eMarkNone);
             }
         }
 
