@@ -1,5 +1,5 @@
 /**********************************************************************************************
-    Copyright (C) 2019 Henri Hornburg hrnbg@t-online.de
+    Copyright (C) 2019 Henri Hornburg <hrnbg@t-online.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@ QMap<QString, searchProperty_e> CSearch::searchPropertyEnumMap;
 QMap<searchProperty_e, QString> CSearch::searchPropertyMeaningMap;
 
 CSearch::CSearch(QString searchstring)
+    : searchText(searchstring)
 {
     //Initialisation
     searchTypeLambdaMap = initSearchTypeLambdaMap();
@@ -47,7 +48,7 @@ CSearch::CSearch(QString searchstring)
         //Make spaces around so for example with is not detected inside without
         if(searchstring.contains(" " + key + " ", Qt::CaseInsensitive))
         {
-            searchTypeKeyword=key;
+            searchTypeKeyword = key;
             break;
         }
     }
@@ -55,29 +56,29 @@ CSearch::CSearch(QString searchstring)
     if(searchTypeKeyword.isEmpty())
     {
         //Default to search for what the user typed in the name or the full text
-        search.searchType=eSearchTypeWith;
+        search.searchType = eSearchTypeWith;
         if(searchMode == eSearchModeText)
         {
-            search.property=searchProperty_e::eSearchPropertyGeneralFullText;
+            search.property = searchProperty_e::eSearchPropertyGeneralFullText;
         }
         else
         {
-            search.property=searchProperty_e::eSearchPropertyGeneralName;
+            search.property = searchProperty_e::eSearchPropertyGeneralName;
         }
         search.searchValue.str1 = searchstring.simplified();
         syntaxError = true;
     }
     else
     {
-        search.searchType=keywordSearchTypeMap.value(searchTypeKeyword);
+        search.searchType = keywordSearchTypeMap.value(searchTypeKeyword);
         //Everything before the Search Type keyword is the property, i.e. "date after 2019" would result in "date"
-        search.property=eSearchPropertyNoMatch;
-        QString propertyString=searchstring.section(searchTypeKeyword, 0, 0, QString::SectionCaseInsensitiveSeps).simplified();
+        search.property = eSearchPropertyNoMatch;
+        QString propertyString = searchstring.section(searchTypeKeyword, 0, 0, QString::SectionCaseInsensitiveSeps).simplified();
         for(const QString& key:searchPropertyEnumMap.keys())
         {
             if(propertyString.compare(key, Qt::CaseInsensitive) == 0)
             {
-                search.property=searchPropertyEnumMap[key];
+                search.property = searchPropertyEnumMap[key];
                 break;
             }
         }
@@ -102,15 +103,15 @@ CSearch::CSearch(QString searchstring)
             QTime time1a = QLocale::system().toTime(filterValueStringFirstPart, tf);
             if(time1a.isValid())
             {
-                filterValue.value1=time1a.msecsSinceStartOfDay()/1000;
-                filterValue.str1="SsE";
+                filterValue.value1 = time1a.msecsSinceStartOfDay() / 1000;
+                filterValue.str1 = "SsE";
             }
 
-            QTime time1b=QLocale::c().toTime(filterValueStringFirstPart, tf);
+            QTime time1b = QLocale::c().toTime(filterValueStringFirstPart, tf);
             if(time1b.isValid())
             {
-                filterValue.value1=time1b.msecsSinceStartOfDay()/1000;
-                filterValue.str1="SsE";
+                filterValue.value1 = time1b.msecsSinceStartOfDay() / 1000;
+                filterValue.str1 = "SsE";
             }
 
             if(time1a.isValid() || time1b.isValid())
@@ -118,15 +119,15 @@ CSearch::CSearch(QString searchstring)
                 QTime time2a = QLocale::system().toTime(filterValueStringSecondPart, tf);
                 if(time2a.isValid())
                 {
-                    filterValue.value2=time2a.msecsSinceStartOfDay()/1000;
-                    filterValue.str2="SsE";
+                    filterValue.value2 = time2a.msecsSinceStartOfDay() / 1000;
+                    filterValue.str2 = "SsE";
                 }
 
-                QTime time2b=QLocale::c().toTime(filterValueStringSecondPart, tf);
+                QTime time2b = QLocale::c().toTime(filterValueStringSecondPart, tf);
                 if(time2b.isValid())
                 {
-                    filterValue.value2=time2b.msecsSinceStartOfDay()/1000;
-                    filterValue.str2="SsE";
+                    filterValue.value2 = time2b.msecsSinceStartOfDay() / 1000;
+                    filterValue.str2 = "SsE";
                 }
                 break;
             }
@@ -151,15 +152,15 @@ CSearch::CSearch(QString searchstring)
                 QDateTime time1a = QLocale::system().toDateTime(filterValueStringFirstPart, df);
                 if(time1a.isValid())
                 {
-                    filterValue.value1=time1a.toSecsSinceEpoch();
-                    filterValue.str1="SsE";
+                    filterValue.value1 = time1a.toSecsSinceEpoch();
+                    filterValue.str1 = "SsE";
                 }
 
-                QDateTime time1b=QLocale::c().toDateTime(filterValueStringFirstPart, df);
+                QDateTime time1b = QLocale::c().toDateTime(filterValueStringFirstPart, df);
                 if(time1b.isValid())
                 {
-                    filterValue.value1=time1b.toSecsSinceEpoch();
-                    filterValue.str1="SsE";
+                    filterValue.value1 = time1b.toSecsSinceEpoch();
+                    filterValue.str1 = "SsE";
                 }
 
                 if(time1a.isValid() || time1b.isValid())
@@ -167,15 +168,15 @@ CSearch::CSearch(QString searchstring)
                     QDateTime time2a = QLocale::system().toDateTime(filterValueStringSecondPart, df);
                     if(time2a.isValid())
                     {
-                        filterValue.value2=time2a.toSecsSinceEpoch();
-                        filterValue.str2="SsE";
+                        filterValue.value2 = time2a.toSecsSinceEpoch();
+                        filterValue.str2 = "SsE";
                     }
 
-                    QDateTime time2b=QLocale::c().toDateTime(filterValueStringSecondPart, df);
+                    QDateTime time2b = QLocale::c().toDateTime(filterValueStringSecondPart, df);
                     if(time2b.isValid())
                     {
-                        filterValue.value2=time2b.toSecsSinceEpoch();
-                        filterValue.str2="SsE";
+                        filterValue.value2 = time2b.toSecsSinceEpoch();
+                        filterValue.str2 = "SsE";
                     }
                     break;
                 }
@@ -199,29 +200,29 @@ CSearch::CSearch(QString searchstring)
             {
                 if(numericArguments.cap(1) != "")     //to avoid removal of NOFLOAT
                 {
-                    filterValue.value1=numericArguments.cap(1).toFloat();
+                    filterValue.value1 = numericArguments.cap(1).toFloat();
                 }
 
-                filterValue.str1=numericArguments.cap(2);
+                filterValue.str1 = numericArguments.cap(2);
 
                 if(numericArguments.cap(3) != "")     //to avoid removal of NOFLOAT
                 {
-                    filterValue.value2=numericArguments.cap(3).toFloat();
+                    filterValue.value2 = numericArguments.cap(3).toFloat();
                 }
 
-                filterValue.str2=numericArguments.cap(4);
+                filterValue.str2 = numericArguments.cap(4);
             }
         }
         if(filterValue.toString().isEmpty())
         {
             filterValue.str1 = filterValueString;
         }
-        search.searchValue=filterValue;
+        search.searchValue = filterValue;
     }
     improveQuery();
     if(search.property == eSearchPropertyNoMatch)
     {
-        syntaxError=true;
+        syntaxError = true;
     }
 }
 
@@ -293,11 +294,11 @@ void CSearch::improveQuery()
     //If the user entered a number with a unit and another number, assume they have the same unit
     if(search.searchValue.str1 != "" && search.searchValue.str2 == "" && search.searchValue.value1 != NOFLOAT && search.searchValue.value2 != NOFLOAT)
     {
-        search.searchValue.str2=search.searchValue.str1;
+        search.searchValue.str2 = search.searchValue.str1;
     }
     if(search.searchValue.str1 == "" && search.searchValue.str2 != "" && search.searchValue.value1 != NOFLOAT && search.searchValue.value2 != NOFLOAT)
     {
-        search.searchValue.str1=search.searchValue.str2;
+        search.searchValue.str1 = search.searchValue.str2;
     }
 
     //Try to guess what property the user meant when there is no match. I.e. make "shorter than 5km" work
@@ -343,14 +344,14 @@ void CSearch::improveQuery()
             //Try to catch if user only entered a year. Not done in regular detecting as it could be a speed or so.
             if(search.searchValue.str1.isEmpty())
             {
-                search.searchValue.value1=QDateTime(QDate(search.searchValue.value1, 1, 1)).toSecsSinceEpoch();
-                search.searchValue.str1="SsE";
+                search.searchValue.value1 = QDateTime(QDate(search.searchValue.value1, 1, 1)).toSecsSinceEpoch();
+                search.searchValue.str1 = "SsE";
             }
             //Assume you want 2012 and not 1912 (qt defaults to 19xx)
             else if(QDateTime::fromSecsSinceEpoch(search.searchValue.value1).addYears(100) <=  QDateTime::currentDateTime())
             {
-                search.searchValue.value1=QDateTime::fromSecsSinceEpoch(search.searchValue.value1).addYears(100).toSecsSinceEpoch();
-                search.searchValue.str1="SsE";
+                search.searchValue.value1 = QDateTime::fromSecsSinceEpoch(search.searchValue.value1).addYears(100).toSecsSinceEpoch();
+                search.searchValue.str1 = "SsE";
             }
         }
         if(search.searchValue.value2 != NOFLOAT)
@@ -358,23 +359,23 @@ void CSearch::improveQuery()
             //Try to catch if user only entered a year. Not done in regular detecting as it could be a speed or so.
             if(search.searchValue.str2.isEmpty())
             {
-                search.searchValue.value2=QDateTime(QDate(search.searchValue.value2, 1, 1)).toSecsSinceEpoch();
-                search.searchValue.str2="SsE";
+                search.searchValue.value2 = QDateTime(QDate(search.searchValue.value2, 1, 1)).toSecsSinceEpoch();
+                search.searchValue.str2 = "SsE";
             }
             //Assume you want 2012 and not 1912 (qt defaults to 19xx)
             else if(QDateTime::fromSecsSinceEpoch(search.searchValue.value2).addYears(100) <=  QDateTime::currentDateTime())
             {
-                search.searchValue.value2=QDateTime::fromSecsSinceEpoch(search.searchValue.value2).addYears(100).toSecsSinceEpoch();
-                search.searchValue.str2="SsE";
+                search.searchValue.value2 = QDateTime::fromSecsSinceEpoch(search.searchValue.value2).addYears(100).toSecsSinceEpoch();
+                search.searchValue.str2 = "SsE";
             }
         }
 
         //If the user searched for 'date equals' change it to 'between 0h and 24h of the day queried'
         if(search.searchType == eSearchTypeEquals)
         {
-            search.searchType=eSearchTypeBetween;
-            search.searchValue.str2="SsE";
-            search.searchValue.value2=search.searchValue.value1 + 24*60*60;
+            search.searchType = eSearchTypeBetween;
+            search.searchValue.str2 = "SsE";
+            search.searchValue.value2 = search.searchValue.value1 + 24 * 60 * 60;
         }
     }
 }
@@ -384,6 +385,7 @@ QMap<QString, CSearch::search_type_e> CSearch::initKeywordSearchTypeMap()
     QMap<QString, search_type_e> map;
     map.insert(tr("with"), eSearchTypeWith);
     map.insert(tr("contains"), eSearchTypeWith);
+    map.insert(tr("contain"), eSearchTypeWith);
     map.insert(tr("containing"), eSearchTypeWith);
     map.insert(tr("without"), eSearchTypeWithout);
     map.insert(tr("shorter than"), eSearchTypeSmaller);
@@ -406,6 +408,7 @@ QMap<QString, CSearch::search_type_e> CSearch::initKeywordSearchTypeMap()
     map.insert(tr("regex"), eSearchTypeRegEx);
     map.insert("=", eSearchTypeEquals);
     map.insert(tr("equals"), eSearchTypeEquals);
+    map.insert(tr("is"), eSearchTypeEquals);
     map.insert(tr("between"), eSearchTypeBetween);
     return map;
 }
@@ -415,7 +418,8 @@ QMap<QString, QString> CSearch::initKeywordSearchExampleMap()
     QMap<QString, QString> map;
     map.insert(tr("with"), tr("example: attributes with dog"));
     map.insert(tr("contains"), tr("example: name contains bike"));
-    map.insert(tr("containing"), tr("example: name containin bike"));
+    map.insert(tr("contain"), tr("example: keywords contain bike"));
+    map.insert(tr("containing"), tr("example: name containing bike"));
     map.insert(tr("without"), tr("example: name without water"));
     map.insert(tr("shorter than"), tr("example: shorter than 5km"));
     map.insert(tr("smaller than"), tr("example: area smaller than 5m²"));
@@ -437,6 +441,7 @@ QMap<QString, QString> CSearch::initKeywordSearchExampleMap()
     map.insert(tr("regex"), tr("example: size regex (regular|large)"));
     map.insert("=", tr("example: size = micro"));
     map.insert(tr("equals"), tr("example: activity equals bike"));
+    map.insert(tr("is"), tr("example: status is available"));
     map.insert(tr("between"), tr("example: length between 20km and 20mi"));
     return map;
 }
@@ -451,6 +456,8 @@ QMap<QString, searchProperty_e> CSearch::initSearchPropertyEnumMap()
     map.insert(tr("date"), eSearchPropertyGeneralDate);
     map.insert(tr("comment"), eSearchPropertyGeneralComment);
     map.insert(tr("description"), eSearchPropertyGeneralDescription);
+    map.insert(tr("rating"), eSearchPropertyGeneralRating);
+    map.insert(tr("keywords"), eSearchPropertyGeneralKeywords);
 
     //Area keywords
     map.insert(tr("area"), eSearchPropertyAreaArea);
@@ -466,6 +473,7 @@ QMap<QString, searchProperty_e> CSearch::initSearchPropertyEnumMap()
     map.insert(tr("size"), eSearchPropertyGeocacheSize);
     map.insert(tr("GCCode"), eSearchPropertyGeocacheGCCode);
     map.insert(tr("GCName"), eSearchPropertyGeocacheGCName);
+    map.insert(tr("status"), eSearchPropertyGeocacheStatus);
 
     //Waypoint keywords
 
@@ -502,6 +510,8 @@ QMap<searchProperty_e, QString> CSearch::initSearchPropertyMeaningMap()
     map.insert(eSearchPropertyGeneralDate, tr("searches the Date"));
     map.insert(eSearchPropertyGeneralComment, tr("searches the Comment"));
     map.insert(eSearchPropertyGeneralDescription, tr("searches the Description"));
+    map.insert(eSearchPropertyGeneralKeywords, tr("searches the Keywords"));
+    map.insert(eSearchPropertyGeneralRating, tr("compares the Rating"));
 
     //Area keywords
     map.insert(eSearchPropertyAreaArea, tr("searches the area"));
@@ -514,6 +524,7 @@ QMap<searchProperty_e, QString> CSearch::initSearchPropertyMeaningMap()
     map.insert(eSearchPropertyGeocacheSize, tr("searches the size of a geocache. (micro, small, regular, large)"));
     map.insert(eSearchPropertyGeocacheGCCode, tr("searches the GCCode of a geocache."));
     map.insert(eSearchPropertyGeocacheGCName, tr("searches the Name of a geocache."));
+    map.insert(eSearchPropertyGeocacheStatus, tr("searches the status of a geocache. (available, not available, archived)"));
 
     //Waypoint keywords
 
