@@ -1,6 +1,6 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
-    Copyright (C) 2019 Henri Hornburg hrnbg@t-online.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
+    Copyright (C) 2019 Henri Hornburg <hrnbg@t-online.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 #include "helpers/CDraw.h"
 #include "helpers/CProgressDialog.h"
 #include "helpers/CSettings.h"
+#include "misc.h"
 
 #include <proj_api.h>
 #include <QtWidgets>
@@ -42,8 +43,8 @@
 #define MIN_DIST_CLOSE_TO   10
 #define MIN_DIST_FOCUS      200
 
-#define WPT_FOCUS_DIST_IN   (50*50)
-#define WPT_FOCUS_DIST_OUT  (200*200)
+#define WPT_FOCUS_DIST_IN   (50 * 50)
+#define WPT_FOCUS_DIST_OUT  (200 * 200)
 
 namespace
 {
@@ -419,14 +420,6 @@ static void addRowLimit(QString& str, const QString& name, const QString& min, c
     str += "</tr>";
 }
 
-static bool sortByName(const QString& item1, const QString& item2)
-{
-    static QCollator collator;
-    // this will set collator to natural sorting mode (instead of lexical)
-    collator.setNumericMode(true);
-    return collator.compare(item1, item2) < 0;
-}
-
 
 QString CGisItemTrk::getInfoLimits() const
 {
@@ -435,7 +428,7 @@ QString CGisItemTrk::getInfoLimits() const
     str += "<tr><th align='left'></th><th align='right'>" + tr("min.") + "</th><th align='right'>" + tr("max.") + "</th></tr>";
 
     QStringList keys = extrema.keys();
-    qSort(keys.begin(), keys.end(), sortByName);
+    qSort(keys.begin(), keys.end(), sortByString);
 
     for(const QString& key : keys)
     {
@@ -568,22 +561,22 @@ QString CGisItemTrk::getInfo(quint32 feature) const
         str += tr("Energy Use Cycling: %L1").arg(energyUseCycling, 0, 'f', 0) + "kcal<br/>";
     }
 
-    if((allValidFlags & (CTrackData::trkpt_t::eValidEle|CTrackData::trkpt_t::eInvalidEle)) == (CTrackData::trkpt_t::eValidEle|CTrackData::trkpt_t::eInvalidEle))
+    if((allValidFlags & (CTrackData::trkpt_t::eValidEle | CTrackData::trkpt_t::eInvalidEle)) == (CTrackData::trkpt_t::eValidEle | CTrackData::trkpt_t::eInvalidEle))
     {
         str += "<b style='color: red;'>" + tr("Invalid elevations!") + "</b><br/>";
     }
 
-    if((allValidFlags & (CTrackData::trkpt_t::eValidTime|CTrackData::trkpt_t::eInvalidTime)) == (CTrackData::trkpt_t::eValidTime|CTrackData::trkpt_t::eInvalidTime))
+    if((allValidFlags & (CTrackData::trkpt_t::eValidTime | CTrackData::trkpt_t::eInvalidTime)) == (CTrackData::trkpt_t::eValidTime | CTrackData::trkpt_t::eInvalidTime))
     {
         str += "<b style='color: red;'>" + tr("Invalid timestamps!") + "</b><br/>";
     }
 
-    if((allValidFlags & (CTrackData::trkpt_t::eValidPos|CTrackData::trkpt_t::eInvalidPos)) == (CTrackData::trkpt_t::eValidPos|CTrackData::trkpt_t::eInvalidPos))
+    if((allValidFlags & (CTrackData::trkpt_t::eValidPos | CTrackData::trkpt_t::eInvalidPos)) == (CTrackData::trkpt_t::eValidPos | CTrackData::trkpt_t::eInvalidPos))
     {
         str += "<b style='color: red;'>" + tr("Invalid positions!") + "</b><br/>";
     }
 
-    if((allValidFlags & (CTrackData::trkpt_t::eValidSlope|CTrackData::trkpt_t::eInvalidSlope)) == (CTrackData::trkpt_t::eValidSlope|CTrackData::trkpt_t::eInvalidSlope))
+    if((allValidFlags & (CTrackData::trkpt_t::eValidSlope | CTrackData::trkpt_t::eInvalidSlope)) == (CTrackData::trkpt_t::eValidSlope | CTrackData::trkpt_t::eInvalidSlope))
     {
         str += "<b style='color: red;'>" + tr("Invalid slopes!") + "</b><br/>";
     }
@@ -630,6 +623,8 @@ QString CGisItemTrk::getInfo(quint32 feature) const
         }
     }
 
+    str += getRatingKeywordInfo();
+
     return str + "</div>";
 }
 
@@ -673,7 +668,7 @@ QString CGisItemTrk::getInfoRange() const
 
         str += QString("%4 %1:%2:%3").arg(hh, 2, 10, QChar('0')).arg(mm, 2, 10, QChar('0')).arg(ss, 2, 10, QChar('0')).arg(QChar(0x231a));
 
-        IUnit::self().meter2speed(distance/deltaTime, val, unit);
+        IUnit::self().meter2speed(distance / deltaTime, val, unit);
         str += QString(", %3 %1%2").arg(val).arg(unit).arg(QChar(0x21A3));
     }
     str += "\n";
@@ -691,20 +686,20 @@ QString CGisItemTrk::getInfoRange() const
     str += QString("%3 %1%2 (%4%5)").arg(val).arg(unit).arg(QChar(0x2197)).arg(val2).arg(unit2);
     if(timeIsValid)
     {
-        IUnit::self().meter2speed(deltaAscent/deltaTime, val, unit);
+        IUnit::self().meter2speed(deltaAscent / deltaTime, val, unit);
         str += QString(", %1%2").arg(val).arg(unit);
     }
     str += "\n";
 
-    tmp    = qAtan(deltaDescent/distance);
-    slope1 = qAbs(tmp * 360.0/(2 * M_PI));
+    tmp    = qAtan(deltaDescent / distance);
+    slope1 = qAbs(tmp * 360.0 / (2 * M_PI));
     IUnit::self().slope2string(slope1, val2, unit2);
 
     IUnit::self().meter2elevation(deltaDescent, val, unit);
     str += QString("%3 %1%2 (%4%5)").arg(val).arg(unit).arg(QChar(0x2198)).arg(val2).arg(unit2);
     if(timeIsValid)
     {
-        IUnit::self().meter2speed(deltaDescent/deltaTime, val, unit);
+        IUnit::self().meter2speed(deltaDescent / deltaTime, val, unit);
         str += QString(", %1%2").arg(val).arg(unit);
     }
 
@@ -758,7 +753,7 @@ QString CGisItemTrk::getInfoTrkPt(const CTrackData::trkpt_t& pt) const
         const CKnownExtension &ext = CKnownExtension::get(key);
         if(ext.known)
         {
-            str += "\n" + ext.nameLongText + ": " + QString("%1%2").arg(ext.valueFunc(pt)*ext.factor, 0, 'f', 1).arg(ext.unit);
+            str += "\n" + ext.nameLongText + ": " + QString("%1%2").arg(ext.valueFunc(pt) * ext.factor, 0, 'f', 1).arg(ext.unit);
         }
         else
         {
@@ -787,35 +782,42 @@ QString CGisItemTrk::getInfoProgress(const CTrackData::trkpt_t& pt) const
     if(pt.ascent != NOFLOAT)
     {
         IUnit::self().meter2elevation(pt.ascent, val, unit);
-        asc = tr("Ascent: %1%2 (%3%)").arg(val).arg(unit).arg(pt.ascent * 100/totalAscent, 2, 'f', 0);
+        asc = tr("Ascent: %1%2 (%3%)").arg(val).arg(unit).arg(pt.ascent * 100 / totalAscent, 2, 'f', 0);
     }
 
     if(pt.descent != NOFLOAT)
     {
         IUnit::self().meter2elevation(pt.descent, val, unit);
-        dsc = tr(", Descent: %1%2 (%3%)").arg(val).arg(unit).arg(pt.descent * 100/totalDescent, 2, 'f', 0);
+        dsc = tr(", Descent: %1%2 (%3%)").arg(val).arg(unit).arg(pt.descent * 100 / totalDescent, 2, 'f', 0);
     }
 
     if(pt.distance != NOFLOAT)
     {
         IUnit::self().meter2distance(pt.distance, val, unit);
-        dst = tr("Distance: %1%2 (%3%)").arg(val).arg(unit).arg(pt.distance * 100/totalDistance, 2, 'f', 0);
+        dst = tr("Distance: %1%2 (%3%)").arg(val).arg(unit).arg(pt.distance * 100 / totalDistance, 2, 'f', 0);
     }
 
     if(pt.elapsedSeconds != NOFLOAT)
     {
         IUnit::self().seconds2time(pt.elapsedSecondsMoving, val, unit);
-        mov = tr(", Moving: %1%2 (%3%)").arg(val).arg(unit).arg(pt.elapsedSecondsMoving * 100/totalElapsedSecondsMoving, 2, 'f', 0);
+        mov = tr(", Moving: %1%2 (%3%)").arg(val).arg(unit).arg(pt.elapsedSecondsMoving * 100 / totalElapsedSecondsMoving, 2, 'f', 0);
     }
 
     return QString("%1%2\n%3%4").arg(asc).arg(dsc).arg(dst).arg(mov);
 }
 
-QString CGisItemTrk::getInfoRange(const CTrackData::trkpt_t& pt1, const CTrackData::trkpt_t& pt2) const
+QString CGisItemTrk::getInfoRange(const CTrackData::trkpt_t& trkpt1, const CTrackData::trkpt_t& trkpt2) const
 {
     QString val, unit;
     qreal dt = NOFLOAT;
 
+    CTrackData::trkpt_t pt1 = trkpt1;
+    CTrackData::trkpt_t pt2 = trkpt2;
+    if(pt1.idxTotal > pt2.idxTotal)
+    {
+        qSwap(pt1, pt2);
+    }
+
     if(pt1.time.isValid() && pt2.time.isValid())
     {
         dt = pt2.time.toTime_t() - pt1.time.toTime_t();
@@ -831,7 +833,7 @@ QString CGisItemTrk::getInfoRange(const CTrackData::trkpt_t& pt1, const CTrackDa
 
         if(dt != NOFLOAT)
         {
-            IUnit::self().meter2speed((pt2.ascent - pt1.ascent)/dt, val, unit);
+            IUnit::self().meter2speed((pt2.ascent - pt1.ascent) / dt, val, unit);
             asc += tr(", %1%2").arg(val).arg(unit);
         }
     }
@@ -843,7 +845,7 @@ QString CGisItemTrk::getInfoRange(const CTrackData::trkpt_t& pt1, const CTrackDa
 
         if(dt != NOFLOAT)
         {
-            IUnit::self().meter2speed((pt2.descent - pt1.descent)/dt, val, unit);
+            IUnit::self().meter2speed((pt2.descent - pt1.descent) / dt, val, unit);
             dsc += tr(", %1%2").arg(val).arg(unit);
         }
     }
@@ -1075,6 +1077,8 @@ void CGisItemTrk::deriveSecondaryData()
         return;
     }
 
+    activities.updateFlags();
+
     CTrackData::trkpt_t * lastValid  = nullptr;
     CTrackData::trkpt_t * lastTrkpt  = nullptr;
     qreal timestampStart = NOFLOAT;
@@ -1107,7 +1111,7 @@ void CGisItemTrk::deriveSecondaryData()
         {
             trkpt.deltaDistance  = lastTrkpt->distanceTo(trkpt);
             trkpt.distance       = lastTrkpt->distance + trkpt.deltaDistance;
-            trkpt.elapsedSeconds = trkpt.time.toMSecsSinceEpoch()/1000.0 - timestampStart;
+            trkpt.elapsedSeconds = trkpt.time.toMSecsSinceEpoch() / 1000.0 - timestampStart;
 
             // ascent descent
             if(lastEle != NOINT)
@@ -1119,7 +1123,7 @@ void CGisItemTrk::deriveSecondaryData()
 
                 if(qAbs(delta) >= ASCENT_THRESHOLD)
                 {
-                    const qint32 step = (delta/ASCENT_THRESHOLD)*ASCENT_THRESHOLD;
+                    const qint32 step = (delta / ASCENT_THRESHOLD) * ASCENT_THRESHOLD;
 
                     if(delta > 0)
                     {
@@ -1144,7 +1148,7 @@ void CGisItemTrk::deriveSecondaryData()
         else
         {
             timeStart      = trkpt.time;
-            timestampStart = timeStart.toMSecsSinceEpoch()/1000.0;
+            timestampStart = timeStart.toMSecsSinceEpoch() / 1000.0;
             lastEle        = trkpt.ele;
 
             trkpt.deltaDistance        = 0;
@@ -1179,7 +1183,7 @@ void CGisItemTrk::deriveSecondaryData()
             {
                 d1 = trkpt2.distance;
                 e1 = trkpt2.ele;
-                t1 = trkpt2.time.toMSecsSinceEpoch()/1000.0;
+                t1 = trkpt2.time.toMSecsSinceEpoch() / 1000.0;
                 break;
             }
         }
@@ -1206,8 +1210,8 @@ void CGisItemTrk::deriveSecondaryData()
 
         if(d1 < d2)
         {
-            qreal a      = qAtan((e2 - e1)/(d2 - d1));
-            trkpt.slope1 = a * 360.0/(2 * M_PI);
+            qreal a      = qAtan((e2 - e1) / (d2 - d1));
+            trkpt.slope1 = a * 360.0 / (2 * M_PI);
             trkpt.slope2 = qTan(trkpt.slope1 * DEG_TO_RAD) * 100;
         }
         else
@@ -1263,7 +1267,7 @@ void CGisItemTrk::deriveSecondaryData()
 
     energyCycling.compute();
 
-    updateVisuals(eVisualPlot|eVisualDetails|eVisualProject|eVisualColorAct|eVisualTrkTable|eVisualTrkInfo, "deriveSecondaryData()");
+    updateVisuals(eVisualAll, "deriveSecondaryData()");
 
 //    qDebug() << "--------------" << getName() << "------------------";
 //    qDebug() << "allValidFlags" << hex << allValidFlags;
@@ -1319,7 +1323,7 @@ void CGisItemTrk::findWaypointsCloseBy(CProgressDialog& progress, quint32& curre
     // convert coordinates of all waypoints into meter coordinates relative to the first track point
     point3D pt0 = line[0];
     QList<trkwpt_t> trkwpts;
-    for(int i=0; i < project->childCount(); i++)
+    for(int i = 0; i < project->childCount(); i++)
     {
         CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(project->child(i));
         if(wpt == nullptr)
@@ -1366,7 +1370,7 @@ void CGisItemTrk::findWaypointsCloseBy(CProgressDialog& progress, quint32& curre
         for(const pointDP &pt : line)
         {
             ++current;
-            qreal d = (trkwpt.x - pt.x)*(trkwpt.x - pt.x) + (trkwpt.y - pt.y)*(trkwpt.y - pt.y);
+            qreal d = (trkwpt.x - pt.x) * (trkwpt.x - pt.x) + (trkwpt.y - pt.y) * (trkwpt.y - pt.y);
 
             if(d < WPT_FOCUS_DIST_IN)
             {
@@ -1421,7 +1425,7 @@ void CGisItemTrk::findWaypointsCloseBy(CProgressDialog& progress, quint32& curre
     {
         deriveSecondaryData();
     }
-    updateVisuals(eVisualDetails|eVisualPlot, "findWaypointsCloseBy()");
+    updateVisuals(eVisualDetails | eVisualPlot, "findWaypointsCloseBy()");
 }
 
 bool CGisItemTrk::isCloseTo(const QPointF& pos)
@@ -1492,7 +1496,7 @@ bool CGisItemTrk::cut()
     if(askToDeleteOriginal)
     {
         // clone first part?
-        if((mode & (CCutTrk::eModeKeepBoth|CCutTrk::eModeKeepFirst)) != 0)
+        if((mode & (CCutTrk::eModeKeepBoth | CCutTrk::eModeKeepFirst)) != 0)
         {
             int idx = cutMode == CCutTrk::eCutMode1 ? idxMouse  - 1 : idxMouse;
             if(idx < 0)
@@ -1511,16 +1515,16 @@ bool CGisItemTrk::cut()
         }
 
         // clone second part?
-        if((mode & (CCutTrk::eModeKeepBoth|CCutTrk::eModeKeepSecond)) != 0)
+        if((mode & (CCutTrk::eModeKeepBoth | CCutTrk::eModeKeepSecond)) != 0)
         {
-            QString name = getName() + QString(" (%1 - %2)").arg(idxMouse).arg(cntTotalPoints-1);
+            QString name = getName() + QString(" (%1 - %2)").arg(idxMouse).arg(cntTotalPoints - 1);
             IGisProject *project = nullptr;
             if(!getNameAndProject(name, project, tr("track")))
             {
                 return false;
             }
 
-            new CGisItemTrk(name, idxMouse, cntTotalPoints-1, trk, project);
+            new CGisItemTrk(name, idxMouse, cntTotalPoints - 1, trk, project);
         }
     }
     else
@@ -1696,23 +1700,13 @@ void CGisItemTrk::combine(const QList<IGisItem::key_t>& keys)
     trk1->updateDecoration(eMarkChanged, eMarkNone);
 }
 
-void CGisItemTrk::hideSelectedPoints()
+bool CGisItemTrk::adjustIndicesForRemoveOperations(qint32& idx1, qint32& idx2)
 {
-    if(!setReadOnlyMode(false))
-    {
-        return;
-    }
-
-    // read start/stop indices
-    qint32 idx1, idx2;
-    getMouseRange(idx1, idx2, true);
-
     if(NOIDX == idx1)
     {
-        return;
+        return false;
     }
 
-
     // if first index is the first point adjust index to hide it, too
     if(trk.isTrkPtFirstVisible(idx1))
     {
@@ -1727,7 +1721,7 @@ void CGisItemTrk::hideSelectedPoints()
     // abort if there is no point between idx1 and idx2
     if(idx1 + 1 == idx2)
     {
-        return;
+        return false;
     }
 
     // special case for a single point
@@ -1736,6 +1730,24 @@ void CGisItemTrk::hideSelectedPoints()
         --idx1;
         ++idx2;
     }
+    return true;
+}
+
+void CGisItemTrk::hideSelectedPoints()
+{
+    if(!setReadOnlyMode(false))
+    {
+        return;
+    }
+
+    // read start/stop indices
+    qint32 idx1, idx2;
+    getMouseRange(idx1, idx2, true);
+
+    if(!adjustIndicesForRemoveOperations(idx1, idx2))
+    {
+        return;
+    }
 
     // iterate over all segments and delete points between idx1 and idx2
     for(CTrackData::trkpt_t& trkpt : trk)
@@ -1746,7 +1758,6 @@ void CGisItemTrk::hideSelectedPoints()
             trkpt.setFlag(CTrackData::trkpt_t::eFlagHidden);
         }
     }
-    resetMouseRange();
     deriveSecondaryData();
     if(idx1 + 1 == idx2 - 1)
     {
@@ -1758,6 +1769,53 @@ void CGisItemTrk::hideSelectedPoints()
     }
 }
 
+void CGisItemTrk::deleteSelectedPoints()
+{
+    if(!setReadOnlyMode(false))
+    {
+        return;
+    }
+
+    // read start/stop indices
+    qint32 idx1, idx2;
+    getMouseRange(idx1, idx2, true);
+
+    if(!adjustIndicesForRemoveOperations(idx1, idx2))
+    {
+        return;
+    }
+
+    for(CTrackData::trkseg_t& seg : trk.segs)
+    {
+        QVector<CTrackData::trkpt_t> pts;
+        for(const CTrackData::trkpt_t &pt : seg.pts)
+        {
+            if(idx1 < pt.idxTotal && pt.idxTotal < idx2)
+            {
+                continue;
+            }
+
+            pts << pt;
+        }
+
+        seg.pts = pts;
+    }
+
+    mouseRange1 = trk.getTrkPtByTotalIndex(idx1);
+    mouseRange2 = trk.getTrkPtByTotalIndex(idx1 + 1);
+    mouseMoveFocus = nullptr;
+
+    deriveSecondaryData();
+    if(idx1 + 1 == idx2 - 1)
+    {
+        changed(tr("Delete point %1.").arg(idx1 + 1), "://icons/48x48/DeleteOne.png");
+    }
+    else
+    {
+        changed(tr("Delete points %1..%2.").arg(idx1 + 1).arg(idx2 - 1), "://icons/48x48/DeleteMultiple.png");
+    }
+}
+
 void CGisItemTrk::showSelectedPoints()
 {
     if(!setReadOnlyMode(false))
@@ -1781,7 +1839,6 @@ void CGisItemTrk::showSelectedPoints()
         }
     }
 
-    resetMouseRange();
     deriveSecondaryData();
     changed(tr("Show points."), "://icons/48x48/PointShow.png");
 }
@@ -2074,12 +2131,13 @@ void CGisItemTrk::drawColorizedByActivity(QPainter& p) const
                 continue;
             }
 
+            p.drawLine(lineSimple[ptPrev->idxVisible], lineSimple[pt.idxVisible]);
+
             if(ptPrev->getAct() != pt.getAct())
             {
                 setPen(p, pen, pt.getAct());
             }
 
-            p.drawLine(lineSimple[ptPrev->idxVisible], lineSimple[pt.idxVisible]);
             ptPrev = &pt;
         }
     }
@@ -2206,20 +2264,20 @@ void CGisItemTrk::setColorizeSource(QString src)
     if(src != getColorizeSource())
     {
         colorSourceLimit.setSource(src);
-        updateHistory(eVisualColorLegend|eVisualDetails);
+        updateHistory(eVisualColorLegend | eVisualDetails);
     }
 }
 
 void CGisItemTrk::setColorizeLimitLow(qreal limit)
 {
     colorSourceLimit.setMin(limit);
-    updateHistory(eVisualColorLegend|eVisualDetails);
+    updateHistory(eVisualColorLegend | eVisualDetails);
 }
 
 void CGisItemTrk::setColorizeLimitHigh(qreal limit)
 {
     colorSourceLimit.setMax(limit);
-    updateHistory(eVisualColorLegend|eVisualDetails);
+    updateHistory(eVisualColorLegend | eVisualDetails);
 }
 
 QString CGisItemTrk::getColorizeUnit() const
@@ -2263,7 +2321,7 @@ void CGisItemTrk::drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis)
         // calculate bounding box of text
         QFont f = CMainWindow::self().getMapFont();
         QFontMetrics fm(f);
-        QRect rectText = fm.boundingRect(QRect(0, 0, 500, 0), Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap, str);
+        QRect rectText = fm.boundingRect(QRect(0, 0, 500, 0), Qt::AlignLeft | Qt::AlignTop | Qt::TextWordWrap, str);
 
         // The initial minimum size of the box will be MIN_WIDTH_INFO_BOX.
         // If a larger box is needed the minimum grows. By that the width
@@ -2318,9 +2376,9 @@ void CGisItemTrk::drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis)
         IUnit::self().meter2distance(mouseMoveFocus->distance, val1, unit1);
         IUnit::self().meter2distance(totalDistance - mouseMoveFocus->distance, val2, unit2);
         p.setPen(Qt::darkBlue);
-        p.drawText(QRect(0, 1, rectBar1.width(), fm.height()), Qt::AlignVCenter|Qt::AlignLeft, QString("%1%2").arg(val1).arg(unit1));
+        p.drawText(QRect(0, 1, rectBar1.width(), fm.height()), Qt::AlignVCenter | Qt::AlignLeft, QString("%1%2").arg(val1).arg(unit1));
         p.drawText(QRect(0, 1, rectBar1.width(), fm.height()), Qt::AlignCenter, QString("%1%").arg(mouseMoveFocus->distance * 100 / totalDistance, 0, 'f', 0));
-        p.drawText(QRect(0, 1, rectBar1.width(), fm.height()), Qt::AlignVCenter|Qt::AlignRight, QString("%1%2").arg(val2).arg(unit2));
+        p.drawText(QRect(0, 1, rectBar1.width(), fm.height()), Qt::AlignVCenter | Qt::AlignRight, QString("%1%2").arg(val2).arg(unit2));
 
         // draw progress bar time
         if(totalElapsedSeconds != 0)
@@ -2338,15 +2396,15 @@ void CGisItemTrk::drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis)
             IUnit::self().seconds2time(mouseMoveFocus->elapsedSecondsMoving, val1, unit1);
             IUnit::self().seconds2time(totalElapsedSecondsMoving - mouseMoveFocus->elapsedSecondsMoving, val2, unit2);
             p.setPen(Qt::darkBlue);
-            p.drawText(QRect(0, 1, rectBar1.width(), fm.height()), Qt::AlignVCenter|Qt::AlignLeft, QString("%1%2").arg(val1).arg(unit1));
+            p.drawText(QRect(0, 1, rectBar1.width(), fm.height()), Qt::AlignVCenter | Qt::AlignLeft, QString("%1%2").arg(val1).arg(unit1));
             p.drawText(QRect(0, 1, rectBar1.width(), fm.height()), Qt::AlignCenter, QString("%1%").arg(mouseMoveFocus->elapsedSecondsMoving * 100 / totalElapsedSecondsMoving, 0, 'f', 0));
-            p.drawText(QRect(0, 1, rectBar1.width(), fm.height()), Qt::AlignVCenter|Qt::AlignRight, QString("%1%2").arg(val2).arg(unit2));
+            p.drawText(QRect(0, 1, rectBar1.width(), fm.height()), Qt::AlignVCenter | Qt::AlignRight, QString("%1%2").arg(val2).arg(unit2));
         }
 
         // draw text
         p.translate(0, fm.height() + 8);
         p.setPen(colorFg);
-        p.drawText(rectText, Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap, str);
+        p.drawText(rectText, Qt::AlignLeft | Qt::AlignTop | Qt::TextWordWrap, str);
 
         p.restore();
     }
@@ -2360,7 +2418,7 @@ void CGisItemTrk::drawItem(QPainter& p, const QRectF& viewport, CGisDraw * gis)
         p.drawPixmap(anchor - QPointF(4, 4), QPixmap(IGisItem::colorMap[colorIdx].bullet));
     }
 
-    drawRange(p);
+    drawRange(p, gis);
 }
 
 void CGisItemTrk::drawLabel(QPainter& p, const QPolygonF&, QList<QRectF>& blockedAreas, const QFontMetricsF& fm, CGisDraw* gis)
@@ -2392,8 +2450,6 @@ void CGisItemTrk::drawLabel(QPainter& p, const QPolygonF&, QList<QRectF>& blocke
             QString labelMin = ext.toString(limit.min, true, key);
             QString labelMax = ext.toString(limit.max, true, key);
 
-            qDebug() << labelMin << labelMax;
-
             if(!labelMin.isEmpty())
             {
                 drawLimitLabels(eLimitTypeMin, labelMin, posMin, p, fm, blockedAreas);
@@ -2430,7 +2486,7 @@ void CGisItemTrk::drawHighlight(QPainter& p)
     }
 }
 
-void CGisItemTrk::drawRange(QPainter& p)
+void CGisItemTrk::drawRange(QPainter& p, CGisDraw* gis)
 {
     QMutexLocker lock(&mutexItems);
 
@@ -2446,11 +2502,41 @@ void CGisItemTrk::drawRange(QPainter& p)
 
     QPolygonF seg = line.mid(idx1, idx2 - idx1 + 1);
 
-    p.setPen(QPen(Qt::darkGreen, penWidthHi, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
-    p.drawPolyline(seg);
+    if(seg.size() == 1)
+    {
+        const auto r1 = qRound(penWidthHi / 2.0);
+        const auto r2 = qRound(penWidthFg / 2.0);
 
-    p.setPen(QPen(Qt::green, penWidthFg, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
-    p.drawPolyline(seg);
+        p.setPen(Qt::NoPen);
+        p.setBrush(Qt::darkGreen);
+        p.drawEllipse(seg[0], r1, r1);
+        p.setBrush(Qt::green);
+        p.drawEllipse(seg[0], r2, r2);
+    }
+    else
+    {
+        p.setPen(QPen(Qt::darkGreen, penWidthHi, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
+        p.drawPolyline(seg);
+
+        p.setPen(QPen(Qt::green, penWidthFg, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin));
+        p.drawPolyline(seg);
+    }
+
+    if(mouseMoveFocus == mouseRange1 || mouseMoveFocus == mouseRange2)
+    {
+        QPointF pt(mouseMoveFocus->lon, mouseMoveFocus->lat);
+        pt *= DEG_TO_RAD;
+        gis->convertRad2Px(pt);
+
+        const auto r1 = qRound(penWidthHi / 2.0) + 1;
+        const auto r2 = qRound(penWidthFg / 2.0) + 1;
+
+        p.setPen(Qt::NoPen);
+        p.setBrush(Qt::darkGreen);
+        p.drawEllipse(pt, r1, r1);
+        p.setBrush(Qt::green);
+        p.drawEllipse(pt, r2, r2);
+    }
 }
 
 bool CGisItemTrk::setMode(mode_e m, const QString& owner)
@@ -2507,7 +2593,7 @@ void CGisItemTrk::setElevation(qint32 idx, qint32 ele)
     {
         trkpt->ele = ele;
         deriveSecondaryData();
-        changed(tr("Changed elevation of point %1 to %2 %3").arg(idx).arg(ele).arg(IUnit::self().baseunit), "://icons/48x48/SetEle.png");
+        changed(tr("Changed elevation of point %1 to %2 %3").arg(idx).arg(ele * IUnit::self().elevationFactor).arg(IUnit::self().elevationUnit), "://icons/48x48/SetEle.png");
     }
 }
 
@@ -2516,7 +2602,7 @@ void CGisItemTrk::setColor(int idx)
     if(idx < IGisItem::getColorMap().count())
     {
         setColor(IGisItem::getColorMap()[idx].color);
-        updateHistory(eVisualColorLegend|eVisualDetails);
+        updateHistory(eVisualColorLegend | eVisualDetails);
     }
 }
 
@@ -2551,12 +2637,6 @@ void CGisItemTrk::setActivityRange(trkact_t act)
         return;
     }
 
-    // special case for a single point
-    if(idx1 == idx2)
-    {
-        --idx1;
-    }
-
     // iterate over all segments and set activity flag for points between idx1 and idx2
     for(CTrackData::trkpt_t& trkpt : trk)
     {
@@ -2566,7 +2646,6 @@ void CGisItemTrk::setActivityRange(trkact_t act)
         }
     }
 
-    resetMouseRange();
     deriveSecondaryData();
     changed(tr("Changed activity to '%1' for range(%2..%3).").arg(desc.name).arg(idx1).arg(idx2), desc.iconLarge);
 }
@@ -2692,6 +2771,7 @@ QPointF CGisItemTrk::setMouseFocusByPoint(const QPoint& pt, focusmode_e fmode, c
         idx = getIdxPointCloseBy(pt, line);
         newPointOfFocus = (mode == eModeRange) ? trk.getTrkPtByTotalIndex(idx) : trk.getTrkPtByVisibleIndex(idx);
     }
+
     if(!publishMouseFocus(newPointOfFocus, fmode, owner))
     {
         newPointOfFocus = nullptr;
@@ -2716,12 +2796,119 @@ bool CGisItemTrk::setMouseFocusByTotalIndex(qint32 idx, focusmode_e fmode, const
     return false;
 }
 
+bool CGisItemTrk::setMouseRangeByTotalIndex(qint32 idx1, qint32 idx2, const QString& owner)
+{
+    if(mode != eModeRange || mouseFocusOwner != owner)
+    {
+        return false;
+    }
+
+    mouseRange1 = trk.getTrkPtByTotalIndex(idx1);
+    mouseRange2 = trk.getTrkPtByTotalIndex(idx2);
+    setMouseFocusVisuals(mouseRange2);
+    setMouseRangeFocusVisuals(mouseRange1, mouseRange2);
+    return true;
+}
+
+bool CGisItemTrk::incMouseRangeBegin(qint32 i, const QString& owner)
+{
+    if(mouseRange1 == nullptr || mouseRange2 == nullptr)
+    {
+        return false;
+    }
+    const CTrackData::trkpt_t * &pt = mouseRange1->idxTotal < mouseRange2->idxTotal ? mouseRange1 : mouseRange2;
+    return moveMouseFocus(pt, qMin(cntTotalPoints - 1, pt->idxTotal + i), owner);
+}
+
+bool CGisItemTrk::decMouseRangeBegin(qint32 i, const QString& owner)
+{
+    if(mouseRange1 == nullptr || mouseRange2 == nullptr)
+    {
+        return false;
+    }
+    const CTrackData::trkpt_t * &pt = mouseRange1->idxTotal < mouseRange2->idxTotal ? mouseRange1 : mouseRange2;
+    return moveMouseFocus(pt, qMax(0, pt->idxTotal - i), owner);
+}
+
+bool CGisItemTrk::incMouseRangeEnd(qint32 i, const QString& owner)
+{
+    if(mouseRange1 == nullptr || mouseRange2 == nullptr)
+    {
+        return false;
+    }
+
+    const CTrackData::trkpt_t * &pt = mouseRange1->idxTotal > mouseRange2->idxTotal ? mouseRange1 : mouseRange2;
+    return moveMouseFocus(pt, qMin(cntTotalPoints - 1, pt->idxTotal + i), owner);
+}
+
+bool CGisItemTrk::decMouseRangeEnd(qint32 i, const QString& owner)
+{
+    if(mouseRange1 == nullptr || mouseRange2 == nullptr)
+    {
+        return false;
+    }
+    const CTrackData::trkpt_t * &pt = mouseRange1->idxTotal > mouseRange2->idxTotal ? mouseRange1 : mouseRange2;
+    return moveMouseFocus(pt, qMax(0, pt->idxTotal - i), owner);
+}
+
+bool CGisItemTrk::moveMouseFocus(const CTrackData::trkpt_t * &pt, qint32 idxNext, const QString& owner)
+{
+    if(mode != eModeRange || mouseFocusOwner != owner)
+    {
+        return false;
+    }
+
+    rangeState = eRangeStateClicked2nd;
+
+    pt = trk.getTrkPtByTotalIndex(idxNext);
+    mouseMoveFocus = pt;
+
+    setMouseFocusVisuals(pt);
+    setMouseRangeFocusVisuals(mouseRange1, mouseRange2);
+    return true;
+}
+
+bool CGisItemTrk::newMouseRangeBegin(const QString& owner)
+{
+    if(mode != eModeRange || mouseFocusOwner != owner || mouseRange1 == nullptr || mouseRange2 == nullptr)
+    {
+        return false;
+    }
+
+    const CTrackData::trkpt_t * pt = mouseRange1->idxTotal < mouseRange2->idxTotal ? mouseRange1 : mouseRange2;
+    mouseRange1 = pt;
+    mouseRange2 = pt;
+    rangeState = eRangeStateClicked2nd;
+    setMouseFocusVisuals(pt);
+    setMouseRangeFocusVisuals(mouseRange1, mouseRange2);
+    return true;
+}
+
+bool CGisItemTrk::newMouseRangeEnd(const QString& owner)
+{
+    if(mode != eModeRange || mouseFocusOwner != owner || mouseRange1 == nullptr || mouseRange2 == nullptr)
+    {
+        return false;
+    }
+
+    const CTrackData::trkpt_t * pt = mouseRange1->idxTotal > mouseRange2->idxTotal ? mouseRange1 : mouseRange2;
+    mouseRange1 = pt;
+    mouseRange2 = pt;
+    rangeState = eRangeStateClicked2nd;
+    setMouseFocusVisuals(pt);
+    setMouseRangeFocusVisuals(mouseRange1, mouseRange2);
+    return true;
+}
 
 void CGisItemTrk::resetMouseRange()
 {
+    mouseClickFocus = nullptr;
+    mouseMoveFocus = nullptr;
     mouseRange1 = nullptr;
     mouseRange2 = nullptr;
     rangeState  = eRangeStateIdle;
+    setMouseFocusVisuals(nullptr);
+    setMouseRangeFocusVisuals(nullptr, nullptr);
 }
 
 bool CGisItemTrk::publishMouseFocus(const CTrackData::trkpt_t * pt, focusmode_e fmode, const QString& owner)
@@ -2749,32 +2936,93 @@ void CGisItemTrk::publishMouseFocusRangeMode(const CTrackData::trkpt_t * pt, foc
     {
     case eRangeStateIdle:
     {
-        if((fmode == eFocusMouseClick) && (pt != nullptr))
+        if(pt == nullptr)
         {
-            mouseRange1 = pt;
-            rangeState  = eRangeState1st;
+            break;
         }
-        break;
-    }
 
-    case eRangeState1st:
-    {
+        mouseMoveFocus = pt;
+        mouseRange1 = pt;
         mouseRange2 = pt;
-        if((fmode == eFocusMouseClick) && (pt != nullptr))
-        {
-            rangeState = eRangeState2nd;
-        }
-        break;
-    }
 
-    case eRangeState2nd:
-    {
         if(fmode == eFocusMouseClick)
         {
-            resetMouseRange();
+            rangeState  = eRangeStateClicked1st;
         }
         break;
     }
+
+    case eRangeStateClicked1st:
+    {
+        if(pt == nullptr)
+        {
+            break;
+        }
+
+        mouseMoveFocus = pt;
+        mouseRange2 = pt;
+        if(fmode == eFocusMouseClick)
+        {
+            rangeState = eRangeStateClicked2nd;
+        }
+        break;
+    }
+
+    case eRangeStateClicked2nd:
+    {
+        mouseMoveFocus = pt;
+
+        if(fmode == eFocusMouseClick)
+        {
+            if(mouseMoveFocus == mouseRange1)
+            {
+                rangeState = eRangeStateMove1st;
+            }
+            else if(mouseMoveFocus == mouseRange2)
+            {
+                rangeState = eRangeStateMove2nd;
+            }
+            else
+            {
+                resetMouseRange();
+            }
+        }
+        break;
+    }
+
+    case eRangeStateMove1st:
+    {
+        if(pt == nullptr)
+        {
+            break;
+        }
+
+        mouseMoveFocus = pt;
+        mouseRange1 = pt;
+        if(fmode == eFocusMouseClick)
+        {
+            rangeState = eRangeStateClicked2nd;
+        }
+
+        break;
+    }
+
+    case eRangeStateMove2nd:
+    {
+        if(pt == nullptr)
+        {
+            break;
+        }
+
+        mouseMoveFocus = pt;
+        mouseRange2 = pt;
+        if(fmode == eFocusMouseClick)
+        {
+            rangeState = eRangeStateClicked2nd;
+        }
+
+        break;
+    }
     }
 
     setMouseFocusVisuals(pt);
@@ -2912,10 +3160,10 @@ void CGisItemTrk::setupInterpolation(bool on, qint32 q)
     }
 
     /// @todo find a better way to scale the algorithm
-    interp.m = interp.Q*50;
+    interp.m = interp.Q * 50;
     if(N < 400)
     {
-        interp.m = N / (16/interp.Q);
+        interp.m = N / (16 / interp.Q);
     }
 
     interp.m &= 0xFFFFFFFE;
@@ -3027,7 +3275,7 @@ QMap<searchProperty_e, CGisItemTrk::fSearch> CGisItemTrk::initKeywordLambdaMap()
     });
     map.insert(eSearchPropertyGeneralFullText, [](CGisItemTrk* item){
         searchValue_t searchValue;
-        searchValue.str1 = item->getInfo(eFeatureShowFullText|eFeatureShowName);
+        searchValue.str1 = item->getInfo(eFeatureShowFullText | eFeatureShowName);
         return searchValue;
     });
     map.insert(eSearchPropertyGeneralElevation, [](CGisItemTrk* item){
@@ -3062,6 +3310,16 @@ QMap<searchProperty_e, CGisItemTrk::fSearch> CGisItemTrk::initKeywordLambdaMap()
         searchValue.str1 = item->getDescription();
         return searchValue;
     });
+    map.insert(eSearchPropertyGeneralRating, [](CGisItemTrk* item){
+        searchValue_t searchValue;
+        searchValue.value1 = item->getRating();
+        return searchValue;
+    });
+    map.insert(eSearchPropertyGeneralKeywords, [](CGisItemTrk* item){
+        searchValue_t searchValue;
+        searchValue.str1 = QStringList(item->getKeywords().toList()).join(", ");
+        return searchValue;
+    });
     //Route / track keywords
     map.insert(eSearchPropertyRteTrkDistance, [](CGisItemTrk* item){
         searchValue_t searchValue;
@@ -3104,26 +3362,26 @@ QMap<searchProperty_e, CGisItemTrk::fSearch> CGisItemTrk::initKeywordLambdaMap()
     });
     map.insert(eSearchPropertyRteTrkAvgSpeed, [](CGisItemTrk* item){
         searchValue_t searchValue;
-        IUnit::self().meter2speed(item->totalDistance/item->totalElapsedSecondsMoving, searchValue.value1, searchValue.str1);
+        IUnit::self().meter2speed(item->totalDistance / item->totalElapsedSecondsMoving, searchValue.value1, searchValue.str1);
         return searchValue;
     });
     map.insert(eSearchPropertyRteTrkActivity, [](CGisItemTrk* item){
         searchValue_t searchValue;
         QStringList strL;
         item->activities.getActivityNames(strL);
-        searchValue.str1=strL.join(", ");
+        searchValue.str1 = strL.join(", ");
         return searchValue;
     });
     map.insert(eSearchPropertyRteTrkTotalTime, [](CGisItemTrk* item){
         searchValue_t searchValue;
         searchValue.value1 = item->totalElapsedSeconds;
-        searchValue.str1="S";
+        searchValue.str1 = "S";
         return searchValue;
     });
     map.insert(eSearchPropertyRteTrkTimeMoving, [](CGisItemTrk* item){
         searchValue_t searchValue;
         searchValue.value1 = item->totalElapsedSecondsMoving;
-        searchValue.str1="S";
+        searchValue.str1 = "S";
         return searchValue;
     });
 
