@@ -1,7 +1,7 @@
 /**********************************************************************************************
-    Copyright (C) 2014 Oliver Eichler oliver.eichler@gmx.de
-    Copyright (C) 2017 Norbert Truchsess norbert.truchsess@t-online.de
-    Copyright (C) 2019 Henri Hornburg hrnbg@t-online.de
+    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>
+    Copyright (C) 2017 Norbert Truchsess <norbert.truchsess@t-online.de>
+    Copyright (C) 2019 Henri Hornburg <hrnbg@t-online.de>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ CGisItemWpt::CGisItemWpt(const QPointF &pos, qreal ele, const QDateTime &time, c
 CGisItemWpt::CGisItemWpt(const QPointF& pos, const QString& name, const QString &icon, IGisProject *project)
     : CGisItemWpt(pos, NOFLOAT, QDateTime::currentDateTimeUtc(), name, icon, project)
 {
-    flags = eFlagCreatedInQms|eFlagWriteAllowed;
+    flags = eFlagCreatedInQms | eFlagWriteAllowed;
     qreal ele = CMainWindow::self().getElevationAt(pos * DEG_TO_RAD);
     wpt.ele = (ele == NOFLOAT) ? NOINT : qRound(ele);
 
@@ -85,7 +85,7 @@ CGisItemWpt::CGisItemWpt(const QPointF& pos, const CGisItemWpt& parentWpt, IGisP
 
     key.clear();
     history.events.clear();
-    flags = eFlagCreatedInQms|eFlagWriteAllowed;
+    flags = eFlagCreatedInQms | eFlagWriteAllowed;
 
     qreal ele = CMainWindow::self().getElevationAt(pos * DEG_TO_RAD);
     wpt.ele = (ele == NOFLOAT) ? NOINT : qRound(ele);
@@ -208,7 +208,7 @@ void CGisItemWpt::genKey() const
 {
     if(geocache.hasData)
     {
-        key.item=QString::number(geocache.id);
+        key.item = QString::number(geocache.id);
     }
     IGisItem::genKey();
 }
@@ -335,7 +335,29 @@ QString CGisItemWpt::getInfo(quint32 feature) const
             str += "<br/>\n";
         }
 
-        str += QString(" %4 (%1, D %2, T %3)").arg(geocache.container).arg(geocache.difficulty, 0, 'f', 1).arg(geocache.terrain, 0, 'f', 1).arg(geocache.name);
+        str += QString(" %4 (%1, D %2, T %3)")
+               .arg(geocache.container)
+               .arg(geocache.difficulty, 0, 'f', 1)
+               .arg(geocache.terrain, 0, 'f', 1)
+               .arg(geocache.name);
+
+        const QDateTime& lastFound = geocache.getLastFound();
+        if(lastFound.isValid())
+        {
+            str += "<br/>" + tr("Last found: %1")
+                   .arg(IUnit::datetime2string(lastFound, false, wpt));
+        }
+
+        const IGisProject * project = getParentProject();
+        if(project != nullptr)
+        {
+            const QDateTime& projectDate = getParentProject()->getTime();
+            if(projectDate.isValid())
+            {
+                str += "<br/>" + tr("Project created: %1")
+                       .arg(IUnit::datetime2string(projectDate, false, wpt));
+            }
+        }
     }
     else
     {
@@ -382,7 +404,7 @@ QString CGisItemWpt::getInfo(quint32 feature) const
             {
                 str += "<br/>\n";
             }
-            str += tr("Created: %1").arg(IUnit::datetime2string(wpt.time, false, QPointF(wpt.lon*DEG_TO_RAD, wpt.lat*DEG_TO_RAD)));
+            str += tr("Created: %1").arg(IUnit::datetime2string(wpt.time, false, QPointF(wpt.lon * DEG_TO_RAD, wpt.lat * DEG_TO_RAD)));
         }
     }
 
@@ -396,8 +418,16 @@ QString CGisItemWpt::getInfo(quint32 feature) const
                 str += QString("<a href='%1'>%2</a>").arg(link.uri.toString()).arg(link.text);
             }
         }
+        //Add logging link separately, since the link to the geocache site is extracted from the gpx file.
+        if(geocache.hasData && geocache.service == eGcCom)
+        {
+            str += " <a href='https://www.geocaching.com/play/geocache/" + wpt.name + "/log'>Log Geocache</a>";
+        }
     }
 
+
+    str += getRatingKeywordInfo();
+
     return str + "</div>";
 }
 
@@ -438,7 +468,14 @@ void CGisItemWpt::setIcon()
 {
     if(geocache.hasData)
     {
-        IGisItem::setIcon(CWptIconManager::self().getWptIconByName(geocache.type, focus));
+        if(geocache.available)
+        {
+            IGisItem::setIcon(CWptIconManager::self().getWptIconByName(geocache.type, focus));
+        }
+        else
+        {
+            IGisItem::setIcon(CWptIconManager::self().getWptIconByName("gray_" + geocache.type, focus));
+        }
     }
     else
     {
@@ -556,7 +593,7 @@ bool CGisItemWpt::isCloseTo(const QPointF& pos)
         return false;
     }
 
-    closeToRadius = abs(QPointF::dotProduct(dist, dist)/radius - radius) < 22;
+    closeToRadius = abs(QPointF::dotProduct(dist, dist) / radius - radius) < 22;
     return closeToRadius;
 }
 
@@ -674,19 +711,19 @@ void CGisItemWpt::drawLabel(QPainter& p, const QPolygonF &viewport, QList<QRectF
     rect.adjust(-2, -2, 2, 2);
 
     // place label on top
-    rect.moveCenter(pt + QPointF(icon.width()/2, -fm.height()));
+    rect.moveCenter(pt + QPointF(icon.width() / 2, -fm.height()));
     if(CDraw::doesOverlap(blockedAreas, rect))
     {
         // place label on bottom
-        rect.moveCenter(pt + QPointF( icon.width()/2, +fm.height() + icon.height()));
+        rect.moveCenter(pt + QPointF( icon.width() / 2, +fm.height() + icon.height()));
         if(CDraw::doesOverlap(blockedAreas, rect))
         {
             // place label on right
-            rect.moveCenter(pt + QPointF( icon.width() + rect.width()/2, +fm.height()));
+            rect.moveCenter(pt + QPointF( icon.width() + rect.width() / 2, +fm.height()));
             if(CDraw::doesOverlap(blockedAreas, rect))
             {
                 // place label on left
-                rect.moveCenter(pt + QPointF( -rect.width()/2, +fm.height()));
+                rect.moveCenter(pt + QPointF( -rect.width() / 2, +fm.height()));
                 if(CDraw::doesOverlap(blockedAreas, rect))
                 {
                     // failed to place label anywhere
@@ -764,7 +801,7 @@ void CGisItemWpt::drawBubble(QPainter& p)
 
 void CGisItemWpt::drawCircle(QPainter& p, const QPointF& pos, const qreal& r, const bool& nogo, const bool& selected)
 {
-    QRect circle(pos.x() - r - 1, pos.y() - r - 1, 2*r + 1, 2*r + 1);
+    QRect circle(pos.x() - r - 1, pos.y() - r - 1, 2 * r + 1, 2 * r + 1);
     p.save();
     p.setBrush(Qt::NoBrush);
     if (selected)
@@ -803,8 +840,8 @@ QPolygonF CGisItemWpt::makePolyline(const QPointF& anchor, const QRectF& r)
 
     if(!r.contains(anchor))
     {
-        qreal w = rectBubble.width()>>1;
-        qreal h = rectBubble.height()>>1;
+        qreal w = rectBubble.width() >> 1;
+        qreal h = rectBubble.height() >> 1;
 
         if(w > 30)
         {
@@ -1005,7 +1042,7 @@ void CGisItemWpt::detBoundingRect()
 {
     if(proximity == NOFLOAT)
     {
-        boundingRect = QRectF(QPointF(wpt.lon, wpt.lat)*DEG_TO_RAD, QPointF(wpt.lon, wpt.lat)*DEG_TO_RAD);
+        boundingRect = QRectF(QPointF(wpt.lon, wpt.lat) * DEG_TO_RAD, QPointF(wpt.lon, wpt.lat) * DEG_TO_RAD);
     }
     else
     {
@@ -1165,6 +1202,38 @@ QList<QString> CGisItemWpt::geocache_t::initAttributeMeaningsTranslated()
     return translated;
 }
 
+QDateTime CGisItemWpt::geocache_t::getLastFound() const
+{
+    QDateTime lastFound;
+    for(const geocachelog_t& log : logs)
+    {
+        if(lastFound.isValid() == false || (log.type == "Found It" && log.date > lastFound))
+        {
+            lastFound = log.date;
+        }
+    }
+    return lastFound;
+}
+
+QString CGisItemWpt::geocache_t::getLogs() const
+{
+    QString strLogs;
+    for(const geocachelog_t& log : logs)
+    {
+        QString thislog = log.text;
+        strLogs += "<p><b>"
+                   + log.date.date().toString(Qt::SystemLocaleShortDate)
+                   + ": "
+                   + log.type
+                   + tr(" by ")
+                   + log.finder
+                   + "</b></p><p>"
+                   + thislog.replace("\n", "<br/>")
+                   + "</p><hr>";
+    }
+    return strLogs;
+}
+
 QMap<searchProperty_e, CGisItemWpt::fSearch> CGisItemWpt::initKeywordLambdaMap()
 {
     QMap<searchProperty_e, CGisItemWpt::fSearch> map;
@@ -1182,7 +1251,7 @@ QMap<searchProperty_e, CGisItemWpt::fSearch> CGisItemWpt::initKeywordLambdaMap()
     });
     map.insert(eSearchPropertyGeneralFullText, [](CGisItemWpt* item){
         searchValue_t searchValue;
-        searchValue.str1 = item->getInfo(eFeatureShowFullText|eFeatureShowName);
+        searchValue.str1 = item->getInfo(eFeatureShowFullText | eFeatureShowName);
         return searchValue;
     });
     map.insert(eSearchPropertyGeneralElevation, [](CGisItemWpt* item){
@@ -1209,6 +1278,16 @@ QMap<searchProperty_e, CGisItemWpt::fSearch> CGisItemWpt::initKeywordLambdaMap()
         searchValue.str1 = item->getDescription();
         return searchValue;
     });
+    map.insert(eSearchPropertyGeneralRating, [](CGisItemWpt* item){
+        searchValue_t searchValue;
+        searchValue.value1 = item->getRating();
+        return searchValue;
+    });
+    map.insert(eSearchPropertyGeneralKeywords, [](CGisItemWpt* item){
+        searchValue_t searchValue;
+        searchValue.str1 = QStringList(item->getKeywords().toList()).join(", ");
+        return searchValue;
+    });
     //Geocache keywords
     map.insert(eSearchPropertyGeocacheDifficulty, [](CGisItemWpt* item){
         searchValue_t searchValue;
@@ -1267,6 +1346,28 @@ QMap<searchProperty_e, CGisItemWpt::fSearch> CGisItemWpt::initKeywordLambdaMap()
         searchValue.str1 = item->geocache.name;
         return searchValue;
     });
+    map.insert(eSearchPropertyGeocacheStatus, [](CGisItemWpt* item){
+        searchValue_t searchValue;
+        if(!item->geocache.hasData)
+        {
+            return searchValue;
+        }
+
+        if(item->geocache.archived)
+        {
+            searchValue.str1 = tr("archived");
+        }
+        else if(item->geocache.available)
+        {
+            searchValue.str1 = tr("available");
+        }
+        else
+        {
+            searchValue.str1 = tr("not available");
+        }
+
+        return searchValue;
+    });
     return map;
 }
 
